% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/glimma.R
\name{doGlimma}
\alias{doGlimma}
\title{A function to generate MA-plots from Glimma, for all contrasts.}
\usage{
doGlimma(tablst, datobj, dsgn, cont, grpvec, padj = "BH",
  sigfilt = 0.05, extraname = NULL, ...)
}
\arguments{
\item{tablst}{An MArrayLM, DGEExact or DGELRT object}

\item{datobj}{A DGEList, ExpressionSet, EList or matrix}

\item{dsgn}{A design matrix}

\item{cont}{A contrast matrix}

\item{grpvec}{A vector of groups, usually what was used to make the design matrix}

\item{padj}{Method for multiplicity adjustment. BH by default}

\item{sigfilt}{Significance cutoff for selecting genes}

\item{extraname}{Used to add a sub-directory to the glimma-plots directory, mainly used to
disambiguate contrasts with the same name (see below).}

\item{...}{Allows end users to pass other arguments to the Glimma glMDPlot function}
}
\value{
A character vector of the files generated, useful for using as links to the output.
}
\description{
This function is designed to parse a design and contrasts matrix in order to
generate Glimma's interactive MA-plots for all contrasts. The heading for the
resulting plot is based on the colnames of the contrasts matrix, so it is important
to include the colnames and make them explanatory.
}
\details{
In addition, if there are multiple contrasts with the same name, say if the same
comparisons are being made for different tissue types, the extraname argument will cause
the output to be placed in glimma-plots/<extraname>, to eliminate over-writing of existing
files.
}
\examples{
  \dontrun{
    mat <- matrix(rnorm(1e6), ncol = 20)
    grps <- factor(1:4, each=5)
    design <- model.matrix(~0 + grps)
    colnames(design) <- LETTERS[1:4]
    contrast <- matrix(c(1,-1,0,0,1,0,-1,0,1,0,0,-1,0,1,-1,0,0,1,0,-1),
    ncol = 5)
    colnames(contrast) <- paste(LETTERS[c(1,1,1,2,2)],
    LETTERS[c(2,3,4,3,4)], sep = " vs ")
    fit <- lmFit(mat, design)
    fit2 <- contrasts.fit(fit, contrast)
    fit2 <- eBayes(fit2)
    htmllinks <- doGlimma(fit2, mat, design, contrast, grps)
   }
}
\author{
James W. MacDonald \email{jmacdon@u.washington.edu}
}
\keyword{manip}
